@@ -34,6 +34,9 @@ class Hypixel:
 
     def __init__(self, api: str):
         self.api = api
+        self.key = hypixel.get_api_stats(self.api)
+        # this could error with InvalidAPIKeyError
+        # this acts as a check to see if the API key provided was valid and also will contain the stats of the key
         self.player = Player(self.api)
         self.guild = Guild(self.api)
         self.leaderboards = Leaderboards(self.api)
@@ -121,7 +124,7 @@ class Guild:
         :param name: A guild name
         :return: Guild
         """
-        return hypixel.get_guild_by_player_uuid(uuid, self.api)
+        return await hypixel.get_guild_by_player_uuid(uuid, self.api)
 
     async def get_by_name(self, name: str):
         """
@@ -131,7 +134,7 @@ class Guild:
         :param name: A guild name
         :return: Guild
         """
-        return hypixel.get_guild_by_name(name, self.api)
+        return await hypixel.get_guild_by_name(name, self.api)
 
 
 class Mojang:
